'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true,
});
exports.default = void 0;
var _react = _interopRequireWildcard(require('react'));
var _reactNative = require('react-native');
var _reactNativeGestureHandler = require('react-native-gesture-handler');
var _reactNativeReanimated = require('react-native-reanimated');
var _utils = require('./utils');
var _colorKit = _interopRequireDefault(require('./colorKit/colorKit'));
var _AppContext = _interopRequireDefault(require('./AppContext'));
function _interopRequireDefault(obj) {
  return obj && obj.__esModule ? obj : { default: obj };
}
function _getRequireWildcardCache(nodeInterop) {
  if (typeof WeakMap !== 'function') return null;
  var cacheBabelInterop = new WeakMap();
  var cacheNodeInterop = new WeakMap();
  return (_getRequireWildcardCache = function (nodeInterop) {
    return nodeInterop ? cacheNodeInterop : cacheBabelInterop;
  })(nodeInterop);
}
function _interopRequireWildcard(obj, nodeInterop) {
  if (!nodeInterop && obj && obj.__esModule) {
    return obj;
  }
  if (obj === null || (typeof obj !== 'object' && typeof obj !== 'function')) {
    return { default: obj };
  }
  var cache = _getRequireWildcardCache(nodeInterop);
  if (cache && cache.has(obj)) {
    return cache.get(obj);
  }
  var newObj = {};
  var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;
  for (var key in obj) {
    if (key !== 'default' && Object.prototype.hasOwnProperty.call(obj, key)) {
      var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;
      if (desc && (desc.get || desc.set)) {
        Object.defineProperty(newObj, key, desc);
      } else {
        newObj[key] = obj[key];
      }
    }
  }
  newObj.default = obj;
  if (cache) {
    cache.set(obj, newObj);
  }
  return newObj;
}
if (_utils.isWeb) {
  // @ts-ignore
  if (!global.setImmediate) global.setImmediate = setTimeout;
  try {
    const { enableExperimentalWebImplementation } = require('react-native-gesture-handler');
    enableExperimentalWebImplementation(true);
  } catch (error) {
    // ignore
  }
}
const ColorPicker = /*#__PURE__*/ (0, _react.forwardRef)((_ref, ref) => {
  let {
    adaptSpectrum = false,
    sliderThickness = 25,
    thumbAnimationDuration = 200,
    thumbSize = 35,
    thumbShape = 'ring',
    boundedThumb = false,
    thumbColor,
    renderThumb,
    thumbStyle,
    thumbInnerStyle,
    value = '#fff',
    onChange,
    onComplete,
    style = {},
    children = /*#__PURE__*/ _react.default.createElement(_reactNative.Text, null, 'NO CHILDREN'),
  } = _ref;
  const initialColor = (0, _react.useRef)(_colorKit.default.HSV(value).object()).current;
  // color's channels values.
  const hueValue = (0, _reactNativeReanimated.useSharedValue)(initialColor.h);
  const saturationValue = (0, _reactNativeReanimated.useSharedValue)(initialColor.s);
  const brightnessValue = (0, _reactNativeReanimated.useSharedValue)(initialColor.v);
  const alphaValue = (0, _reactNativeReanimated.useSharedValue)(initialColor.a);
  const returnedResults = color => {
    color = color ?? {
      h: hueValue.value,
      s: saturationValue.value,
      v: brightnessValue.value,
      a: alphaValue.value,
    };
    return {
      hex: _colorKit.default.HEX(color),
      rgb: _colorKit.default.RGB(color).string(false),
      rgba: _colorKit.default.RGB(color).string(true),
      hsl: _colorKit.default.HSL(color).string(false),
      hsla: _colorKit.default.HSL(color).string(true),
      hsv: _colorKit.default.HSV(color).string(false),
      hsva: _colorKit.default.HSV(color).string(true),
      hwb: _colorKit.default.HWB(color).string(false),
      hwba: _colorKit.default.HWB(color).string(true),
    };
  };
  const onGestureEnd = color => {
    onComplete === null || onComplete === void 0 ? void 0 : onComplete(returnedResults(color));
  };
  const onGestureChange = color => {
    onChange === null || onChange === void 0 ? void 0 : onChange(returnedResults(color));
  };
  const setColor = function (color) {
    let duration = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : thumbAnimationDuration;
    const { h, s, v, a } = _colorKit.default.HSV(color).object();
    hueValue.value = (0, _reactNativeReanimated.withTiming)(h, {
      duration,
    });
    saturationValue.value = (0, _reactNativeReanimated.withTiming)(s, {
      duration,
    });
    brightnessValue.value = (0, _reactNativeReanimated.withTiming)(v, {
      duration,
    });
    alphaValue.value = (0, _reactNativeReanimated.withTiming)(a, {
      duration,
    });
  };
  (0, _react.useEffect)(() => {
    setColor(value);
  }, [value]);
  (0, _react.useImperativeHandle)(ref, () => ({
    setColor,
  }));
  const ctxValue = {
    hueValue,
    saturationValue,
    brightnessValue,
    alphaValue,
    adaptSpectrum,
    sliderThickness,
    thumbSize,
    thumbShape,
    boundedThumb,
    thumbColor,
    renderThumb,
    thumbStyle,
    thumbInnerStyle,
    value,
    setColor,
    returnedResults,
    onGestureEnd,
    onGestureChange,
  };
  return /*#__PURE__*/ _react.default.createElement(
    _reactNativeGestureHandler.GestureHandlerRootView,
    {
      style: [
        {
          direction: _utils.isWeb ? 'ltr' : undefined,
        },
        style,
      ],
    },
    /*#__PURE__*/ _react.default.createElement(
      _AppContext.default.Provider,
      {
        value: ctxValue,
      },
      children
    )
  );
});
var _default = ColorPicker;
exports.default = _default;
//# sourceMappingURL=ColorPicker.js.map
