'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true,
});
exports.InputWidget = InputWidget;
var _react = _interopRequireWildcard(require('react'));
var _reactNative = require('react-native');
var _styles = require('../../styles');
var _utils = require('../../utils');
var _AppContext = _interopRequireDefault(require('../../AppContext'));
var _HexWidget = _interopRequireDefault(require('./Widgets/HexWidget'));
var _RgbWidget = _interopRequireDefault(require('./Widgets/RgbWidget'));
var _HslWidget = _interopRequireDefault(require('./Widgets/HslWidget'));
var _HwbWidget = _interopRequireDefault(require('./Widgets/HwbWidget'));
var _HsvWidget = _interopRequireDefault(require('./Widgets/HsvWidget'));
function _interopRequireDefault(obj) {
  return obj && obj.__esModule ? obj : { default: obj };
}
function _getRequireWildcardCache(nodeInterop) {
  if (typeof WeakMap !== 'function') return null;
  var cacheBabelInterop = new WeakMap();
  var cacheNodeInterop = new WeakMap();
  return (_getRequireWildcardCache = function (nodeInterop) {
    return nodeInterop ? cacheNodeInterop : cacheBabelInterop;
  })(nodeInterop);
}
function _interopRequireWildcard(obj, nodeInterop) {
  if (!nodeInterop && obj && obj.__esModule) {
    return obj;
  }
  if (obj === null || (typeof obj !== 'object' && typeof obj !== 'function')) {
    return { default: obj };
  }
  var cache = _getRequireWildcardCache(nodeInterop);
  if (cache && cache.has(obj)) {
    return cache.get(obj);
  }
  var newObj = {};
  var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;
  for (var key in obj) {
    if (key !== 'default' && Object.prototype.hasOwnProperty.call(obj, key)) {
      var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;
      if (desc && (desc.get || desc.set)) {
        Object.defineProperty(newObj, key, desc);
      } else {
        newObj[key] = obj[key];
      }
    }
  }
  newObj.default = obj;
  if (cache) {
    cache.set(obj, newObj);
  }
  return newObj;
}
const defaultFormats = ['HEX', 'RGB', 'HSL', 'HWB', 'HSV'];
function InputWidget(_ref) {
  let {
    defaultFormat = 'HEX',
    formats = defaultFormats,
    iconColor = 'black',
    containerStyle = {},
    inputStyle = {},
    inputTitleStyle = {},
    iconStyle = {},
    inputProps = {},
  } = _ref;
  const { setColor, returnedResults, hueValue, saturationValue, brightnessValue, alphaValue, onGestureChange, onGestureEnd } = (0,
  _react.useContext)(_AppContext.default);
  const [format, setFormat] = (0, _react.useState)(formats.includes(defaultFormat) ? defaultFormat : formats[0] ?? 'HEX');
  const onChange = color => {
    setColor(color);
    onGestureChange(color);
    onGestureEnd(color);
  };
  const cycle = () => {
    const index = formats.indexOf(format);
    const nextIndex = (index + 1) % formats.length;
    setFormat(formats[nextIndex]);
  };
  const inputsProps = {
    onChange,
    returnedResults,
    hueValue,
    saturationValue,
    brightnessValue,
    alphaValue,
    inputStyle,
    inputTitleStyle,
    inputProps,
  };
  const Input = () => {
    switch (format) {
      case 'HEX':
        return /*#__PURE__*/ _react.default.createElement(_HexWidget.default, inputsProps);
      case 'RGB':
        return /*#__PURE__*/ _react.default.createElement(_RgbWidget.default, inputsProps);
      case 'HSL':
        return /*#__PURE__*/ _react.default.createElement(_HslWidget.default, inputsProps);
      case 'HWB':
        return /*#__PURE__*/ _react.default.createElement(_HwbWidget.default, inputsProps);
      case 'HSV':
        return /*#__PURE__*/ _react.default.createElement(_HsvWidget.default, inputsProps);
    }
  };
  const gap = (0, _utils.getStyle)(containerStyle, 'gap') ?? 5;
  const iconWidth = (0, _utils.getStyle)(iconStyle, 'width') ?? 24;
  const buttonIconStyle = _reactNative.StyleSheet.flatten([_styles.styles.arrowButton, iconStyle]);
  return /*#__PURE__*/ _react.default.createElement(
    _reactNative.View,
    {
      style: [_styles.styles.container, containerStyle],
    },
    /*#__PURE__*/ _react.default.createElement(
      _reactNative.View,
      {
        style: [
          _styles.styles.inputsWrapper,
          {
            gap,
          },
        ],
      },
      /*#__PURE__*/ _react.default.createElement(Input, null)
    ),
    /*#__PURE__*/ _react.default.createElement(
      _utils.ConditionalRendering,
      {
        render: formats.length > 1,
      },
      /*#__PURE__*/ _react.default.createElement(
        _reactNative.View,
        {
          style: {
            width: iconWidth,
          },
        },
        /*#__PURE__*/ _react.default.createElement(
          _reactNative.Pressable,
          {
            onPress: cycle,
          },
          /*#__PURE__*/ _react.default.createElement(_reactNative.Image, {
            style: [
              buttonIconStyle,
              {
                tintColor: iconColor,
              },
            ],
            source: require('../../assets/arrow-icon.png'),
          })
        ),
        /*#__PURE__*/ _react.default.createElement(
          _reactNative.Text,
          {
            style: _styles.styles.inputTitle,
          },
          ' '
        )
      )
    )
  );
}
//# sourceMappingURL=InputWidget.js.map
