'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true,
});
exports.default = HslWidget;
var _react = _interopRequireWildcard(require('react'));
var _reactNativeReanimated = require('react-native-reanimated');
var _WidgetTextInput = _interopRequireDefault(require('./WidgetTextInput'));
var _colorKit = _interopRequireDefault(require('../../../colorKit/colorKit'));
var _utils = require('../../../utils');
function _interopRequireDefault(obj) {
  return obj && obj.__esModule ? obj : { default: obj };
}
function _getRequireWildcardCache(nodeInterop) {
  if (typeof WeakMap !== 'function') return null;
  var cacheBabelInterop = new WeakMap();
  var cacheNodeInterop = new WeakMap();
  return (_getRequireWildcardCache = function (nodeInterop) {
    return nodeInterop ? cacheNodeInterop : cacheBabelInterop;
  })(nodeInterop);
}
function _interopRequireWildcard(obj, nodeInterop) {
  if (!nodeInterop && obj && obj.__esModule) {
    return obj;
  }
  if (obj === null || (typeof obj !== 'object' && typeof obj !== 'function')) {
    return { default: obj };
  }
  var cache = _getRequireWildcardCache(nodeInterop);
  if (cache && cache.has(obj)) {
    return cache.get(obj);
  }
  var newObj = {};
  var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;
  for (var key in obj) {
    if (key !== 'default' && Object.prototype.hasOwnProperty.call(obj, key)) {
      var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;
      if (desc && (desc.get || desc.set)) {
        Object.defineProperty(newObj, key, desc);
      } else {
        newObj[key] = obj[key];
      }
    }
  }
  newObj.default = obj;
  if (cache) {
    cache.set(obj, newObj);
  }
  return newObj;
}
function HslWidget(_ref) {
  let {
    onChange,
    returnedResults,
    hueValue,
    saturationValue,
    brightnessValue,
    alphaValue,
    inputStyle,
    inputTitleStyle,
    inputProps,
  } = _ref;
  const [hslValues, setHslValues] = (0, _react.useState)(_colorKit.default.HSL(returnedResults().hsla).object());
  const isFocused = (0, _react.useRef)(false);
  const updateText = () => {
    const { h, s, l, a } = _colorKit.default.HSL(returnedResults().hsla).object();
    if (!isFocused.current)
      setHslValues({
        h,
        s,
        l,
        a,
      });
  };
  (0, _reactNativeReanimated.useDerivedValue)(
    (function () {
      const _f = function () {
        [hueValue.value, saturationValue.value, brightnessValue.value, alphaValue.value]; // To track changes
        (0, _reactNativeReanimated.runOnJS)(updateText)();
      };
      _f._closure = {
        hueValue,
        saturationValue,
        brightnessValue,
        alphaValue,
        runOnJS: _reactNativeReanimated.runOnJS,
        updateText,
      };
      _f.asString =
        'function _f(){const{hueValue,saturationValue,brightnessValue,alphaValue,runOnJS,updateText}=jsThis._closure;{[hueValue.value,saturationValue.value,brightnessValue.value,alphaValue.value];runOnJS(updateText)();}}';
      _f.__workletHash = 8119592659489;
      _f.__location =
        'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\InputWidget\\Widgets\\HslWidget.tsx (30:18)';
      return _f;
    })(),
    []
  );
  const onHueChange = text => {
    let hue = +text;
    hue = (0, _utils.clamp)(isNaN(hue) ? 0 : hue, 360);
    setHslValues(prev => ({
      ...prev,
      h: hue,
    }));
    onChange(`hsla(${hue}, ${hslValues.s}%, ${hslValues.l}%, ${hslValues.a})`);
  };
  const onSaturationChange = text => {
    let saturation = +text;
    saturation = (0, _utils.clamp)(isNaN(saturation) ? 0 : saturation, 100);
    setHslValues(prev => ({
      ...prev,
      s: saturation,
    }));
    onChange(`hsla(${hslValues.h}, ${saturation}%, ${hslValues.l}%, ${hslValues.a})`);
  };
  const onLumChange = text => {
    let lum = +text;
    lum = (0, _utils.clamp)(isNaN(lum) ? 0 : lum, 100);
    setHslValues(prev => ({
      ...prev,
      l: lum,
    }));
    onChange(`hsla(${hslValues.h}, ${hslValues.s}%, ${lum}%, ${hslValues.a})`);
  };
  const onAlphaChange = text => {
    let alpha = parseFloat(text);
    alpha = (0, _utils.clamp)(isNaN(alpha) ? 0 : alpha, 1);
    setHslValues(prev => ({
      ...prev,
      a: alpha,
    }));
    onChange(`hsla(${hslValues.h}, ${hslValues.s}%, ${hslValues.l}%, ${alpha})`);
  };
  const onFocus = () => {
    isFocused.current = true;
  };
  const onBlur = () => {
    isFocused.current = false;
  };
  return /*#__PURE__*/ _react.default.createElement(
    _react.default.Fragment,
    null,
    /*#__PURE__*/ _react.default.createElement(_WidgetTextInput.default, {
      inputStyle: inputStyle,
      textStyle: inputTitleStyle,
      value: hslValues.h,
      title: 'H',
      onChange: onHueChange,
      onBlur: onBlur,
      onFocus: onFocus,
      inputProps: inputProps,
    }),
    /*#__PURE__*/ _react.default.createElement(_WidgetTextInput.default, {
      inputStyle: inputStyle,
      textStyle: inputTitleStyle,
      value: hslValues.s,
      title: 'S',
      onChange: onSaturationChange,
      onBlur: onBlur,
      onFocus: onFocus,
      inputProps: inputProps,
    }),
    /*#__PURE__*/ _react.default.createElement(_WidgetTextInput.default, {
      inputStyle: inputStyle,
      textStyle: inputTitleStyle,
      value: hslValues.l,
      title: 'L',
      onChange: onLumChange,
      onBlur: onBlur,
      onFocus: onFocus,
      inputProps: inputProps,
    }),
    /*#__PURE__*/ _react.default.createElement(_WidgetTextInput.default, {
      inputStyle: inputStyle,
      textStyle: inputTitleStyle,
      value: hslValues.a,
      title: 'A',
      onChange: onAlphaChange,
      onBlur: onBlur,
      onFocus: onFocus,
      inputProps: inputProps,
      decimal: true,
    })
  );
}
//# sourceMappingURL=HslWidget.js.map
