'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true,
});
exports.default = WidgetTextInput;
var _react = _interopRequireWildcard(require('react'));
var _reactNative = require('react-native');
var _utils = require('../../../utils');
var _styles = require('../../../styles');
function _getRequireWildcardCache(nodeInterop) {
  if (typeof WeakMap !== 'function') return null;
  var cacheBabelInterop = new WeakMap();
  var cacheNodeInterop = new WeakMap();
  return (_getRequireWildcardCache = function (nodeInterop) {
    return nodeInterop ? cacheNodeInterop : cacheBabelInterop;
  })(nodeInterop);
}
function _interopRequireWildcard(obj, nodeInterop) {
  if (!nodeInterop && obj && obj.__esModule) {
    return obj;
  }
  if (obj === null || (typeof obj !== 'object' && typeof obj !== 'function')) {
    return { default: obj };
  }
  var cache = _getRequireWildcardCache(nodeInterop);
  if (cache && cache.has(obj)) {
    return cache.get(obj);
  }
  var newObj = {};
  var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;
  for (var key in obj) {
    if (key !== 'default' && Object.prototype.hasOwnProperty.call(obj, key)) {
      var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;
      if (desc && (desc.get || desc.set)) {
        Object.defineProperty(newObj, key, desc);
      } else {
        newObj[key] = obj[key];
      }
    }
  }
  newObj.default = obj;
  if (cache) {
    cache.set(obj, newObj);
  }
  return newObj;
}
function _extends() {
  _extends = Object.assign
    ? Object.assign.bind()
    : function (target) {
        for (var i = 1; i < arguments.length; i++) {
          var source = arguments[i];
          for (var key in source) {
            if (Object.prototype.hasOwnProperty.call(source, key)) {
              target[key] = source[key];
            }
          }
        }
        return target;
      };
  return _extends.apply(this, arguments);
}
function WidgetTextInput(_ref) {
  let {
    value,
    decimal = false,
    textKeyboard = false,
    title,
    inputStyle,
    textStyle,
    inputProps,
    onChange,
    onBlur,
    onFocus,
  } = _ref;
  const [textValue, setTextValue] = (0, _react.useState)(value + '');
  const inputRef = (0, _react.useRef)(null);
  const onTextValueChange = text => {
    const regex = /^(\d*\.?\d{0,2}|\.\d{1,2})$/;
    const numberValue = parseFloat(text);
    if (isNaN(numberValue) || !regex.test(text)) text = '0';
    if (numberValue < 0 || numberValue > 1) text = (0, _utils.clamp)(numberValue, 1).toString();
    if (!text.includes('.') && text.length > 1) text = text[1];
    setTextValue(text);
    onChange(text);
  };
  (0, _react.useEffect)(() => {
    if (decimal) setTextValue(value + '');
  }, [value]);
  (0, _react.useEffect)(() => {
    const hideSubscription = _reactNative.Keyboard.addListener('keyboardDidHide', () => {
      inputRef.current.blur();
    });
    return () => hideSubscription.remove();
  }, []);
  return /*#__PURE__*/ _react.default.createElement(
    _reactNative.View,
    {
      style: _styles.styles.inputsContainer,
    },
    /*#__PURE__*/ _react.default.createElement(
      _reactNative.TextInput,
      _extends(
        {
          ref: inputRef,
          style: [_styles.styles.input, inputStyle],
          value: decimal ? textValue : value + '',
          maxLength: decimal ? 4 : textKeyboard ? 9 : 3,
          onChangeText: decimal ? onTextValueChange : onChange,
          onBlur: onBlur,
          onFocus: onFocus,
          keyboardType: decimal ? 'decimal-pad' : textKeyboard ? 'default' : 'number-pad',
          autoComplete: 'off',
          autoCorrect: false,
        },
        inputProps,
        {
          selectTextOnFocus: !textKeyboard,
        }
      )
    ),
    /*#__PURE__*/ _react.default.createElement(
      _reactNative.Text,
      {
        style: [_styles.styles.inputTitle, textStyle],
      },
      title
    )
  );
}
//# sourceMappingURL=WidgetTextInput.js.map
