import React, { useContext, useState } from 'react';
import { View, Text, Pressable, Image, StyleSheet } from 'react-native';
import { styles } from '../../styles';
import { ConditionalRendering, getStyle } from '../../utils';
import pickerContext from '../../AppContext';
import HexWidget from './Widgets/HexWidget';
import RgbWidget from './Widgets/RgbWidget';
import HslWidget from './Widgets/HslWidget';
import HwbWidget from './Widgets/HwbWidget';
import HsvWidget from './Widgets/HsvWidget';
const defaultFormats = ['HEX', 'RGB', 'HSL', 'HWB', 'HSV'];
export function InputWidget(_ref) {
  let {
    defaultFormat = 'HEX',
    formats = defaultFormats,
    iconColor = 'black',
    containerStyle = {},
    inputStyle = {},
    inputTitleStyle = {},
    iconStyle = {},
    inputProps = {},
  } = _ref;
  const { setColor, returnedResults, hueValue, saturationValue, brightnessValue, alphaValue, onGestureChange, onGestureEnd } =
    useContext(pickerContext);
  const [format, setFormat] = useState(formats.includes(defaultFormat) ? defaultFormat : formats[0] ?? 'HEX');
  const onChange = color => {
    setColor(color);
    onGestureChange(color);
    onGestureEnd(color);
  };
  const cycle = () => {
    const index = formats.indexOf(format);
    const nextIndex = (index + 1) % formats.length;
    setFormat(formats[nextIndex]);
  };
  const inputsProps = {
    onChange,
    returnedResults,
    hueValue,
    saturationValue,
    brightnessValue,
    alphaValue,
    inputStyle,
    inputTitleStyle,
    inputProps,
  };
  const Input = () => {
    switch (format) {
      case 'HEX':
        return /*#__PURE__*/ React.createElement(HexWidget, inputsProps);
      case 'RGB':
        return /*#__PURE__*/ React.createElement(RgbWidget, inputsProps);
      case 'HSL':
        return /*#__PURE__*/ React.createElement(HslWidget, inputsProps);
      case 'HWB':
        return /*#__PURE__*/ React.createElement(HwbWidget, inputsProps);
      case 'HSV':
        return /*#__PURE__*/ React.createElement(HsvWidget, inputsProps);
    }
  };
  const gap = getStyle(containerStyle, 'gap') ?? 5;
  const iconWidth = getStyle(iconStyle, 'width') ?? 24;
  const buttonIconStyle = StyleSheet.flatten([styles.arrowButton, iconStyle]);
  return /*#__PURE__*/ React.createElement(
    View,
    {
      style: [styles.container, containerStyle],
    },
    /*#__PURE__*/ React.createElement(
      View,
      {
        style: [
          styles.inputsWrapper,
          {
            gap,
          },
        ],
      },
      /*#__PURE__*/ React.createElement(Input, null)
    ),
    /*#__PURE__*/ React.createElement(
      ConditionalRendering,
      {
        render: formats.length > 1,
      },
      /*#__PURE__*/ React.createElement(
        View,
        {
          style: {
            width: iconWidth,
          },
        },
        /*#__PURE__*/ React.createElement(
          Pressable,
          {
            onPress: cycle,
          },
          /*#__PURE__*/ React.createElement(Image, {
            style: [
              buttonIconStyle,
              {
                tintColor: iconColor,
              },
            ],
            source: require('../../assets/arrow-icon.png'),
          })
        ),
        /*#__PURE__*/ React.createElement(
          Text,
          {
            style: styles.inputTitle,
          },
          ' '
        )
      )
    )
  );
}
//# sourceMappingURL=InputWidget.js.map
