import React, { useRef, useState } from 'react';
import { runOnJS, useDerivedValue } from 'react-native-reanimated';
import WidgetTextInput from './WidgetTextInput';
import colorKit from '../../../colorKit/colorKit';
import { clamp } from '../../../utils';
export default function HsvWidget(_ref) {
  let {
    onChange,
    returnedResults,
    hueValue,
    saturationValue,
    brightnessValue,
    alphaValue,
    inputStyle,
    inputTitleStyle,
    inputProps,
  } = _ref;
  const [hsvValues, setHsvValues] = useState(colorKit.HSV(returnedResults().hsva).object());
  const isFocused = useRef(false);
  const updateText = () => {
    const { h, s, v, a } = colorKit.HSV(returnedResults().hsva).object();
    if (!isFocused.current)
      setHsvValues({
        h,
        s,
        v,
        a,
      });
  };
  useDerivedValue(
    (function () {
      const _f = function () {
        [hueValue.value, saturationValue.value, brightnessValue.value, alphaValue.value]; // To track changes
        runOnJS(updateText)();
      };
      _f._closure = {
        hueValue,
        saturationValue,
        brightnessValue,
        alphaValue,
        runOnJS,
        updateText,
      };
      _f.asString =
        'function _f(){const{hueValue,saturationValue,brightnessValue,alphaValue,runOnJS,updateText}=jsThis._closure;{[hueValue.value,saturationValue.value,brightnessValue.value,alphaValue.value];runOnJS(updateText)();}}';
      _f.__workletHash = 8119592659489;
      _f.__location =
        'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\InputWidget\\Widgets\\HsvWidget.tsx (30:18)';
      return _f;
    })(),
    []
  );
  const onHueChange = text => {
    let hue = +text;
    hue = clamp(isNaN(hue) ? 0 : hue, 360);
    setHsvValues(prev => ({
      ...prev,
      h: hue,
    }));
    onChange(`hsva(${hue}, ${hsvValues.s}%, ${hsvValues.v}%, ${hsvValues.a})`);
  };
  const onSaturationChange = text => {
    let saturation = +text;
    saturation = clamp(isNaN(saturation) ? 0 : saturation, 100);
    setHsvValues(prev => ({
      ...prev,
      s: saturation,
    }));
    onChange(`hsva(${hsvValues.h}, ${saturation}%, ${hsvValues.v}%, ${hsvValues.a})`);
  };
  const onValueChange = text => {
    let value = +text;
    value = clamp(isNaN(value) ? 0 : value, 100);
    setHsvValues(prev => ({
      ...prev,
      v: value,
    }));
    onChange(`hsva(${hsvValues.h}, ${hsvValues.s}%, ${value}%, ${hsvValues.a})`);
  };
  const onAlphaChange = text => {
    let alpha = parseFloat(text);
    alpha = clamp(isNaN(alpha) ? 0 : alpha, 1);
    setHsvValues(prev => ({
      ...prev,
      a: alpha,
    }));
    onChange(`hsva(${hsvValues.h}, ${hsvValues.s}%, ${hsvValues.v}%, ${alpha})`);
  };
  const onFocus = () => {
    isFocused.current = true;
  };
  const onBlur = () => {
    isFocused.current = false;
  };
  return /*#__PURE__*/ React.createElement(
    React.Fragment,
    null,
    /*#__PURE__*/ React.createElement(WidgetTextInput, {
      inputStyle: inputStyle,
      textStyle: inputTitleStyle,
      value: hsvValues.h,
      title: 'H',
      onChange: onHueChange,
      onBlur: onBlur,
      onFocus: onFocus,
      inputProps: inputProps,
    }),
    /*#__PURE__*/ React.createElement(WidgetTextInput, {
      inputStyle: inputStyle,
      textStyle: inputTitleStyle,
      value: hsvValues.s,
      title: 'S',
      onChange: onSaturationChange,
      onBlur: onBlur,
      onFocus: onFocus,
      inputProps: inputProps,
    }),
    /*#__PURE__*/ React.createElement(WidgetTextInput, {
      inputStyle: inputStyle,
      textStyle: inputTitleStyle,
      value: hsvValues.v,
      title: 'V',
      onChange: onValueChange,
      onBlur: onBlur,
      onFocus: onFocus,
      inputProps: inputProps,
    }),
    /*#__PURE__*/ React.createElement(WidgetTextInput, {
      inputStyle: inputStyle,
      textStyle: inputTitleStyle,
      value: hsvValues.a,
      title: 'A',
      onChange: onAlphaChange,
      onBlur: onBlur,
      onFocus: onFocus,
      inputProps: inputProps,
      decimal: true,
    })
  );
}
//# sourceMappingURL=HsvWidget.js.map
