import React, { useRef, useState } from 'react';
import { runOnJS, useDerivedValue } from 'react-native-reanimated';
import WidgetTextInput from './WidgetTextInput';
import colorKit from '../../../colorKit/colorKit';
import { clamp } from '../../../utils';
export default function HwbWidget(_ref) {
  let {
    onChange,
    returnedResults,
    hueValue,
    saturationValue,
    brightnessValue,
    alphaValue,
    inputStyle,
    inputTitleStyle,
    inputProps,
  } = _ref;
  const [hwbValues, setHwbValues] = useState(colorKit.HWB(returnedResults().hwba).object());
  const isFocused = useRef(false);
  const updateText = () => {
    const { h, w, b, a } = colorKit.HWB(returnedResults().hwba).object();
    if (!isFocused.current)
      setHwbValues({
        h,
        w,
        b,
        a,
      });
  };
  useDerivedValue(
    (function () {
      const _f = function () {
        [hueValue.value, saturationValue.value, brightnessValue.value, alphaValue.value]; // To track changes
        runOnJS(updateText)();
      };
      _f._closure = {
        hueValue,
        saturationValue,
        brightnessValue,
        alphaValue,
        runOnJS,
        updateText,
      };
      _f.asString =
        'function _f(){const{hueValue,saturationValue,brightnessValue,alphaValue,runOnJS,updateText}=jsThis._closure;{[hueValue.value,saturationValue.value,brightnessValue.value,alphaValue.value];runOnJS(updateText)();}}';
      _f.__workletHash = 8119592659489;
      _f.__location =
        'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\InputWidget\\Widgets\\HwbWidget.tsx (30:18)';
      return _f;
    })(),
    []
  );
  const onHueChange = text => {
    let hue = +text;
    hue = clamp(isNaN(hue) ? 0 : hue, 360);
    setHwbValues(prev => ({
      ...prev,
      h: hue,
    }));
    onChange(`hwba(${hue}, ${hwbValues.w}%, ${hwbValues.b}%, ${hwbValues.a})`);
  };
  const onWhiteChange = text => {
    let whiteness = +text;
    whiteness = clamp(isNaN(whiteness) ? 0 : whiteness, 100);
    setHwbValues(prev => ({
      ...prev,
      w: whiteness,
    }));
    onChange(`hwba(${hwbValues.h}, ${whiteness}%, ${hwbValues.b}%, ${hwbValues.a})`);
  };
  const onBlackChange = text => {
    let blackness = +text;
    blackness = clamp(isNaN(blackness) ? 0 : blackness, 100);
    setHwbValues(prev => ({
      ...prev,
      b: blackness,
    }));
    onChange(`hwba(${hwbValues.h}, ${hwbValues.w}%, ${blackness}%, ${hwbValues.a})`);
  };
  const onAlphaChange = text => {
    let alpha = parseFloat(text);
    alpha = clamp(isNaN(alpha) ? 0 : alpha, 1);
    setHwbValues(prev => ({
      ...prev,
      a: alpha,
    }));
    onChange(`hwba(${hwbValues.h}, ${hwbValues.w}%, ${hwbValues.b}%, ${alpha})`);
  };
  const onFocus = () => {
    isFocused.current = true;
  };
  const onBlur = () => {
    isFocused.current = false;
  };
  return /*#__PURE__*/ React.createElement(
    React.Fragment,
    null,
    /*#__PURE__*/ React.createElement(WidgetTextInput, {
      inputStyle: inputStyle,
      textStyle: inputTitleStyle,
      value: hwbValues.h,
      title: 'H',
      onChange: onHueChange,
      onBlur: onBlur,
      onFocus: onFocus,
      inputProps: inputProps,
    }),
    /*#__PURE__*/ React.createElement(WidgetTextInput, {
      inputStyle: inputStyle,
      textStyle: inputTitleStyle,
      value: hwbValues.w,
      title: 'W',
      onChange: onWhiteChange,
      onBlur: onBlur,
      onFocus: onFocus,
      inputProps: inputProps,
    }),
    /*#__PURE__*/ React.createElement(WidgetTextInput, {
      inputStyle: inputStyle,
      textStyle: inputTitleStyle,
      value: hwbValues.b,
      title: 'B',
      onChange: onBlackChange,
      onBlur: onBlur,
      onFocus: onFocus,
      inputProps: inputProps,
    }),
    /*#__PURE__*/ React.createElement(WidgetTextInput, {
      inputStyle: inputStyle,
      textStyle: inputTitleStyle,
      value: hwbValues.a,
      title: 'A',
      onChange: onAlphaChange,
      onBlur: onBlur,
      onFocus: onFocus,
      inputProps: inputProps,
      decimal: true,
    })
  );
}
//# sourceMappingURL=HwbWidget.js.map
