function _extends() {
  _extends = Object.assign
    ? Object.assign.bind()
    : function (target) {
        for (var i = 1; i < arguments.length; i++) {
          var source = arguments[i];
          for (var key in source) {
            if (Object.prototype.hasOwnProperty.call(source, key)) {
              target[key] = source[key];
            }
          }
        }
        return target;
      };
  return _extends.apply(this, arguments);
}
import React, { useEffect, useRef, useState } from 'react';
import { View, TextInput, Text, Keyboard } from 'react-native';
import { clamp } from '../../../utils';
import { styles } from '../../../styles';
export default function WidgetTextInput(_ref) {
  let {
    value,
    decimal = false,
    textKeyboard = false,
    title,
    inputStyle,
    textStyle,
    inputProps,
    onChange,
    onBlur,
    onFocus,
  } = _ref;
  const [textValue, setTextValue] = useState(value + '');
  const inputRef = useRef(null);
  const onTextValueChange = text => {
    const regex = /^(\d*\.?\d{0,2}|\.\d{1,2})$/;
    const numberValue = parseFloat(text);
    if (isNaN(numberValue) || !regex.test(text)) text = '0';
    if (numberValue < 0 || numberValue > 1) text = clamp(numberValue, 1).toString();
    if (!text.includes('.') && text.length > 1) text = text[1];
    setTextValue(text);
    onChange(text);
  };
  useEffect(() => {
    if (decimal) setTextValue(value + '');
  }, [value]);
  useEffect(() => {
    const hideSubscription = Keyboard.addListener('keyboardDidHide', () => {
      inputRef.current.blur();
    });
    return () => hideSubscription.remove();
  }, []);
  return /*#__PURE__*/ React.createElement(
    View,
    {
      style: styles.inputsContainer,
    },
    /*#__PURE__*/ React.createElement(
      TextInput,
      _extends(
        {
          ref: inputRef,
          style: [styles.input, inputStyle],
          value: decimal ? textValue : value + '',
          maxLength: decimal ? 4 : textKeyboard ? 9 : 3,
          onChangeText: decimal ? onTextValueChange : onChange,
          onBlur: onBlur,
          onFocus: onFocus,
          keyboardType: decimal ? 'decimal-pad' : textKeyboard ? 'default' : 'number-pad',
          autoComplete: 'off',
          autoCorrect: false,
        },
        inputProps,
        {
          selectTextOnFocus: !textKeyboard,
        }
      )
    ),
    /*#__PURE__*/ React.createElement(
      Text,
      {
        style: [styles.inputTitle, textStyle],
      },
      title
    )
  );
}
//# sourceMappingURL=WidgetTextInput.js.map
