import React, { useContext, useCallback } from 'react';
import { Image, View } from 'react-native';
import { GestureDetector, Gesture } from 'react-native-gesture-handler';
import Animated, { runOnJS, useAnimatedStyle, useSharedValue, withTiming } from 'react-native-reanimated';
import { clamp, getStyle, isRtl } from '../../utils';
import { styles } from '../../styles';
import pickerContext from '../../AppContext';
import Thumb from '../Thumb/Thumb';
export function Panel1(_ref) {
  let {
    thumbShape: localThumbShape,
    thumbSize: localThumbSize,
    thumbColor: localThumbColor,
    boundedThumb: localBoundedThumb,
    renderThumb: localRenderThumb,
    thumbStyle: localThumbStyle,
    thumbInnerStyle: localThumbInnerStyle,
    style = {},
  } = _ref;
  const {
    hueValue,
    saturationValue,
    brightnessValue,
    onGestureChange,
    onGestureEnd,
    thumbSize: globalThumbsSize,
    thumbShape: globalThumbShape,
    thumbColor: globalThumbsColor,
    boundedThumb: globalBoundedThumb,
    renderThumb: globalRenderThumbs,
    thumbStyle: globalThumbsStyle,
    thumbInnerStyle: globalThumbsInnerStyle,
  } = useContext(pickerContext);
  const thumbShape = localThumbShape ?? globalThumbShape,
    thumbSize = localThumbSize ?? globalThumbsSize,
    thumbColor = localThumbColor ?? globalThumbsColor,
    boundedThumb = localBoundedThumb ?? globalBoundedThumb,
    renderThumb = localRenderThumb ?? globalRenderThumbs,
    thumbStyle = localThumbStyle ?? globalThumbsStyle ?? {},
    thumbInnerStyle = localThumbInnerStyle ?? globalThumbsInnerStyle ?? {};
  const borderRadius = getStyle(style, 'borderRadius') ?? 5,
    getHeight = getStyle(style, 'height') ?? 200;
  const width = useSharedValue(0),
    height = useSharedValue(0);
  const handleScale = useSharedValue(1);
  const handleStyle = useAnimatedStyle(
    (function () {
      const _f = function () {
        const length = {
            x: width.value - (boundedThumb ? thumbSize : 0),
            y: height.value - (boundedThumb ? thumbSize : 0),
          },
          percentX = (saturationValue.value / 100) * length.x,
          posX = percentX - (boundedThumb ? 0 : thumbSize / 2),
          percentY = (brightnessValue.value / 100) * length.y,
          posY = length.y - percentY - (boundedThumb ? 0 : thumbSize / 2);
        return {
          transform: [
            {
              translateX: posX,
            },
            {
              translateY: posY,
            },
            {
              scale: handleScale.value,
            },
          ],
        };
      };
      _f._closure = {
        width,
        boundedThumb,
        thumbSize,
        height,
        saturationValue,
        brightnessValue,
        handleScale,
      };
      _f.asString =
        'function _f(){const{width,boundedThumb,thumbSize,height,saturationValue,brightnessValue,handleScale}=jsThis._closure;{const length={x:width.value-(boundedThumb?thumbSize:0),y:height.value-(boundedThumb?thumbSize:0)},percentX=saturationValue.value/100*length.x,posX=percentX-(boundedThumb?0:thumbSize/2),percentY=brightnessValue.value/100*length.y,posY=length.y-percentY-(boundedThumb?0:thumbSize/2);return{transform:[{translateX:posX},{translateY:posY},{scale:handleScale.value}]};}}';
      _f.__workletHash = 4307723403877;
      _f.__location = 'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Panels\\Panel1.tsx (56:39)';
      _f.__optimalization = 3;
      return _f;
    })(),
    [localThumbSize]
  );
  const activeColorStyle = useAnimatedStyle(
    (function () {
      const _f = () => ({
        backgroundColor: `hsl(${hueValue.value}, 100%, 50%)`,
      });
      _f._closure = {
        hueValue,
      };
      _f.asString =
        'function _f(){const{hueValue}=jsThis._closure;{return{backgroundColor:"hsl("+hueValue.value+", 100%, 50%)"};}}';
      _f.__workletHash = 6857493922654;
      _f.__location = 'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Panels\\Panel1.tsx (67:44)';
      _f.__optimalization = 3;
      return _f;
    })()
  );
  const onGestureUpdate = (function () {
    const _f = function (_ref2) {
      let { x, y } = _ref2;
      const lengthX = width.value - (boundedThumb ? thumbSize : 0),
        lengthY = height.value - (boundedThumb ? thumbSize : 0),
        posX = clamp(x - (boundedThumb ? thumbSize / 2 : 0), lengthX),
        posY = clamp(y - (boundedThumb ? thumbSize / 2 : 0), lengthY),
        newSaturationValue = Math.round((posX / lengthX) * 100),
        newBrightnessValue = Math.round(100 - (posY / lengthY) * 100);
      if (saturationValue.value === newSaturationValue && brightnessValue.value === newBrightnessValue) return;
      saturationValue.value = newSaturationValue;
      brightnessValue.value = newBrightnessValue;
      runOnJS(onGestureChange)();
    };
    _f._closure = {
      width,
      boundedThumb,
      thumbSize,
      height,
      clamp,
      saturationValue,
      brightnessValue,
      runOnJS,
      onGestureChange,
    };
    _f.asString =
      'function _f({x:x,y:y}){const{width,boundedThumb,thumbSize,height,clamp,saturationValue,brightnessValue,runOnJS,onGestureChange}=jsThis._closure;{const lengthX=width.value-(boundedThumb?thumbSize:0),lengthY=height.value-(boundedThumb?thumbSize:0),posX=clamp(x-(boundedThumb?thumbSize/2:0),lengthX),posY=clamp(y-(boundedThumb?thumbSize/2:0),lengthY),newSaturationValue=Math.round(posX/lengthX*100),newBrightnessValue=Math.round(100-posY/lengthY*100);if(saturationValue.value===newSaturationValue&&brightnessValue.value===newBrightnessValue)return;saturationValue.value=newSaturationValue;brightnessValue.value=newBrightnessValue;runOnJS(onGestureChange)();}}';
    _f.__workletHash = 8504701298242;
    _f.__location = 'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Panels\\Panel1.tsx (69:26)';
    return _f;
  })();
  const onGestureBegin = (function () {
    const _f = function (event) {
      handleScale.value = withTiming(1.2, {
        duration: 100,
      });
      onGestureUpdate(event);
    };
    _f._closure = {
      handleScale,
      withTiming,
      onGestureUpdate,
    };
    _f.asString =
      'function _f(event){const{handleScale,withTiming,onGestureUpdate}=jsThis._closure;{handleScale.value=withTiming(1.2,{duration:100});onGestureUpdate(event);}}';
    _f.__workletHash = 14773240202957;
    _f.__location = 'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Panels\\Panel1.tsx (85:25)';
    return _f;
  })();
  const onGestureFinish = (function () {
    const _f = function () {
      handleScale.value = withTiming(1, {
        duration: 100,
      });
      runOnJS(onGestureEnd)();
    };
    _f._closure = {
      handleScale,
      withTiming,
      runOnJS,
      onGestureEnd,
    };
    _f.asString =
      'function _f(){const{handleScale,withTiming,runOnJS,onGestureEnd}=jsThis._closure;{handleScale.value=withTiming(1,{duration:100});runOnJS(onGestureEnd)();}}';
    _f.__workletHash = 6379049506140;
    _f.__location = 'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Panels\\Panel1.tsx (90:26)';
    return _f;
  })();
  const pan = Gesture.Pan().onBegin(onGestureBegin).onUpdate(onGestureUpdate).onEnd(onGestureFinish);
  const tap = Gesture.Tap().onTouchesUp(onGestureFinish);
  const longPress = Gesture.LongPress().onTouchesUp(onGestureFinish);
  const composed = Gesture.Exclusive(pan, tap, longPress);
  const onLayout = useCallback(_ref3 => {
    let {
      nativeEvent: { layout },
    } = _ref3;
    width.value = layout.width;
    height.value = layout.height;
  }, []);
  const rotateBrightnessImage = useAnimatedStyle(
    (function () {
      const _f = () => ({
        width: height.value,
        height: width.value,
        transform: [
          {
            rotate: '270deg',
          },
          {
            translateX: (width.value - height.value) / 2,
          },
          {
            translateY: ((width.value - height.value) / 2) * (isRtl ? -1 : 1),
          },
        ],
      });
      _f._closure = {
        height,
        width,
        isRtl,
      };
      _f.asString =
        "function _f(){const{height,width,isRtl}=jsThis._closure;{return{width:height.value,height:width.value,transform:[{rotate:'270deg'},{translateX:(width.value-height.value)/2},{translateY:(width.value-height.value)/2*(isRtl?-1:1)}]};}}";
      _f.__workletHash = 9002111915821;
      _f.__location = 'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Panels\\Panel1.tsx (106:49)';
      _f.__optimalization = 3;
      return _f;
    })()
  );
  return /*#__PURE__*/ React.createElement(
    GestureDetector,
    {
      gesture: composed,
    },
    /*#__PURE__*/ React.createElement(
      Animated.View,
      {
        onLayout: onLayout,
        style: [
          styles.panel_container,
          {
            height: getHeight,
          },
          style,
          {
            position: 'relative',
            borderWidth: 0,
            padding: 0,
          },
          activeColorStyle,
        ],
      },
      /*#__PURE__*/ React.createElement(
        View,
        {
          style: [
            styles.panel_image,
            {
              borderRadius,
            },
          ],
        },
        /*#__PURE__*/ React.createElement(Image, {
          source: require('../../assets/blackGradient.png'),
          style: [
            styles.panel_image,
            {
              tintColor: '#fff',
            },
          ],
          resizeMode: 'stretch',
        }),
        /*#__PURE__*/ React.createElement(Animated.Image, {
          source: require('../../assets/blackGradient.png'),
          style: [styles.panel_image, rotateBrightnessImage],
          resizeMode: 'stretch',
        })
      ),
      /*#__PURE__*/ React.createElement(Thumb, {
        thumbShape,
        thumbSize,
        thumbColor,
        renderThumb,
        innerStyle: thumbInnerStyle,
        style: thumbStyle,
        handleStyle,
      })
    )
  );
}
//# sourceMappingURL=Panel1.js.map
