import React, { useContext, useCallback } from 'react';
import { Image, View } from 'react-native';
import { GestureDetector, Gesture } from 'react-native-gesture-handler';
import Animated, { runOnJS, useAnimatedStyle, useSharedValue, withTiming } from 'react-native-reanimated';
import { styles } from '../../styles';
import pickerContext from '../../AppContext';
import { clamp, getStyle, isRtl } from '../../utils';
import Thumb from '../Thumb/Thumb';
export function Panel4(_ref) {
  let {
    thumbColor: localThumbColor,
    boundedThumb: localBoundedThumb,
    renderThumb: localRenderThumb,
    thumbShape: localThumbShape,
    thumbSize: localThumbSize,
    thumbStyle: localThumbStyle,
    thumbInnerStyle: localThumbInnerStyle,
    reverseHue = false,
    reverseHorizontalChannels = false,
    style = {},
  } = _ref;
  const {
    hueValue,
    saturationValue,
    brightnessValue,
    onGestureChange,
    onGestureEnd,
    thumbSize: globalThumbsSize,
    thumbShape: globalThumbShape,
    thumbColor: globalThumbsColor,
    boundedThumb: globalBoundedThumb,
    renderThumb: globalRenderThumbs,
    thumbStyle: globalThumbsStyle,
    thumbInnerStyle: globalThumbsInnerStyle,
  } = useContext(pickerContext);
  const thumbShape = localThumbShape ?? globalThumbShape,
    thumbSize = localThumbSize ?? globalThumbsSize,
    thumbColor = localThumbColor ?? globalThumbsColor,
    boundedThumb = localBoundedThumb ?? globalBoundedThumb,
    renderThumb = localRenderThumb ?? globalRenderThumbs,
    thumbStyle = localThumbStyle ?? globalThumbsStyle ?? {},
    thumbInnerStyle = localThumbInnerStyle ?? globalThumbsInnerStyle ?? {};
  const borderRadius = getStyle(style, 'borderRadius') ?? 5,
    getHeight = getStyle(style, 'height') ?? 200;
  const width = useSharedValue(0),
    height = useSharedValue(0);
  const handleScale = useSharedValue(1);
  const handleStyle = useAnimatedStyle(
    (function () {
      const _f = function () {
        const length = {
            x: width.value - (boundedThumb ? thumbSize : 0),
            y: height.value - (boundedThumb ? thumbSize : 0),
          },
          calcThumb = boundedThumb ? 0 : thumbSize / 2,
          // saturation
          saturationPercentX = (saturationValue.value / 100) * (length.x / 2),
          saturationPosX = (reverseHorizontalChannels ? length.x - saturationPercentX : saturationPercentX) - calcThumb,
          // brightness
          brightnessPercentX = (brightnessValue.value / 100) * (length.x / 2),
          brightnessPosX = (reverseHorizontalChannels ? brightnessPercentX : length.x - brightnessPercentX) - calcThumb,
          // both
          isSaturationActive = reverseHorizontalChannels
            ? saturationPosX > length.x / 2 - calcThumb
            : saturationPosX < length.x / 2 - calcThumb,
          posX = isSaturationActive ? saturationPosX : brightnessPosX,
          // hue
          percentY = (hueValue.value / 360) * length.y,
          posY = (reverseHue ? percentY : length.y - percentY) - calcThumb;
        return {
          transform: [
            {
              translateX: posX,
            },
            {
              translateY: posY,
            },
            {
              scale: handleScale.value,
            },
          ],
        };
      };
      _f._closure = {
        width,
        boundedThumb,
        thumbSize,
        height,
        saturationValue,
        reverseHorizontalChannels,
        brightnessValue,
        hueValue,
        reverseHue,
        handleScale,
      };
      _f.asString =
        'function _f(){const{width,boundedThumb,thumbSize,height,saturationValue,reverseHorizontalChannels,brightnessValue,hueValue,reverseHue,handleScale}=jsThis._closure;{const length={x:width.value-(boundedThumb?thumbSize:0),y:height.value-(boundedThumb?thumbSize:0)},calcThumb=boundedThumb?0:thumbSize/2,saturationPercentX=saturationValue.value/100*(length.x/2),saturationPosX=(reverseHorizontalChannels?length.x-saturationPercentX:saturationPercentX)-calcThumb,brightnessPercentX=brightnessValue.value/100*(length.x/2),brightnessPosX=(reverseHorizontalChannels?brightnessPercentX:length.x-brightnessPercentX)-calcThumb,isSaturationActive=reverseHorizontalChannels?saturationPosX>length.x/2-calcThumb:saturationPosX<length.x/2-calcThumb,posX=isSaturationActive?saturationPosX:brightnessPosX,percentY=hueValue.value/360*length.y,posY=(reverseHue?percentY:length.y-percentY)-calcThumb;return{transform:[{translateX:posX},{translateY:posY},{scale:handleScale.value}]};}}';
      _f.__workletHash = 10490230347205;
      _f.__location = 'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Panels\\Panel4.tsx (58:39)';
      _f.__optimalization = 3;
      return _f;
    })(),
    [localThumbSize, reverseHue, reverseHorizontalChannels]
  );
  const onGestureUpdate = (function () {
    const _f = function (_ref2) {
      let { x, y } = _ref2;
      const lengthX = width.value - (boundedThumb ? thumbSize : 0),
        lengthY = height.value - (boundedThumb ? thumbSize : 0),
        posX = clamp(x - (boundedThumb ? thumbSize / 2 : 0), lengthX),
        posY = clamp(y - (boundedThumb ? thumbSize / 2 : 0), lengthY),
        valueX = Math.round((posX / lengthX) * 200),
        valueY = Math.round((posY / lengthY) * 360),
        newHueValue = reverseHue ? valueY : 360 - valueY,
        newSaturationValue = clamp(reverseHorizontalChannels ? 200 - valueX : valueX, 100),
        newBrightnessValue = clamp(reverseHorizontalChannels ? valueX : 200 - valueX, 100);
      if (
        hueValue.value === newHueValue &&
        saturationValue.value === newSaturationValue &&
        brightnessValue.value === newBrightnessValue
      )
        return;
      hueValue.value = newHueValue;
      saturationValue.value = newSaturationValue;
      brightnessValue.value = newBrightnessValue;
      runOnJS(onGestureChange)();
    };
    _f._closure = {
      width,
      boundedThumb,
      thumbSize,
      height,
      clamp,
      reverseHue,
      reverseHorizontalChannels,
      hueValue,
      saturationValue,
      brightnessValue,
      runOnJS,
      onGestureChange,
    };
    _f.asString =
      'function _f({x:x,y:y}){const{width,boundedThumb,thumbSize,height,clamp,reverseHue,reverseHorizontalChannels,hueValue,saturationValue,brightnessValue,runOnJS,onGestureChange}=jsThis._closure;{const lengthX=width.value-(boundedThumb?thumbSize:0),lengthY=height.value-(boundedThumb?thumbSize:0),posX=clamp(x-(boundedThumb?thumbSize/2:0),lengthX),posY=clamp(y-(boundedThumb?thumbSize/2:0),lengthY),valueX=Math.round(posX/lengthX*200),valueY=Math.round(posY/lengthY*360),newHueValue=reverseHue?valueY:360-valueY,newSaturationValue=clamp(reverseHorizontalChannels?200-valueX:valueX,100),newBrightnessValue=clamp(reverseHorizontalChannels?valueX:200-valueX,100);if(hueValue.value===newHueValue&&saturationValue.value===newSaturationValue&&brightnessValue.value===newBrightnessValue)return;hueValue.value=newHueValue;saturationValue.value=newSaturationValue;brightnessValue.value=newBrightnessValue;runOnJS(onGestureChange)();}}';
    _f.__workletHash = 15687744026353;
    _f.__location = 'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Panels\\Panel4.tsx (81:26)';
    return _f;
  })();
  const onGestureBegin = (function () {
    const _f = function (event) {
      handleScale.value = withTiming(1.2, {
        duration: 100,
      });
      onGestureUpdate(event);
    };
    _f._closure = {
      handleScale,
      withTiming,
      onGestureUpdate,
    };
    _f.asString =
      'function _f(event){const{handleScale,withTiming,onGestureUpdate}=jsThis._closure;{handleScale.value=withTiming(1.2,{duration:100});onGestureUpdate(event);}}';
    _f.__workletHash = 14773240202957;
    _f.__location = 'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Panels\\Panel4.tsx (105:25)';
    return _f;
  })();
  const onGestureFinish = (function () {
    const _f = function () {
      handleScale.value = withTiming(1, {
        duration: 100,
      });
      runOnJS(onGestureEnd)();
    };
    _f._closure = {
      handleScale,
      withTiming,
      runOnJS,
      onGestureEnd,
    };
    _f.asString =
      'function _f(){const{handleScale,withTiming,runOnJS,onGestureEnd}=jsThis._closure;{handleScale.value=withTiming(1,{duration:100});runOnJS(onGestureEnd)();}}';
    _f.__workletHash = 6379049506140;
    _f.__location = 'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Panels\\Panel4.tsx (110:26)';
    return _f;
  })();
  const pan = Gesture.Pan().onBegin(onGestureBegin).onUpdate(onGestureUpdate).onEnd(onGestureFinish);
  const tap = Gesture.Tap().onTouchesUp(onGestureFinish);
  const longPress = Gesture.LongPress().onTouchesUp(onGestureFinish);
  const composed = Gesture.Exclusive(pan, tap, longPress);
  const onLayout = useCallback(_ref3 => {
    let {
      nativeEvent: { layout },
    } = _ref3;
    width.value = layout.width;
    height.value = layout.height;
  }, []);
  const rotatePanelImage = useAnimatedStyle(
    (function () {
      const _f = () => ({
        width: height.value,
        height: width.value,
        transform: [
          {
            scaleY: reverseHue ? -1 : 1,
          },
          {
            rotate: '270deg',
          },
          {
            translateX: ((width.value - height.value) / 2) * (reverseHue ? -1 : 1),
          },
          {
            translateY: ((width.value - height.value) / 2) * (isRtl ? -1 : 1),
          },
        ],
      });
      _f._closure = {
        height,
        width,
        reverseHue,
        isRtl,
      };
      _f.asString =
        "function _f(){const{height,width,reverseHue,isRtl}=jsThis._closure;{return{width:height.value,height:width.value,transform:[{scaleY:reverseHue?-1:1},{rotate:'270deg'},{translateX:(width.value-height.value)/2*(reverseHue?-1:1)},{translateY:(width.value-height.value)/2*(isRtl?-1:1)}]};}}";
      _f.__workletHash = 8519187383491;
      _f.__location = 'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Panels\\Panel4.tsx (126:44)';
      _f.__optimalization = 3;
      return _f;
    })()
  );
  return /*#__PURE__*/ React.createElement(
    GestureDetector,
    {
      gesture: composed,
    },
    /*#__PURE__*/ React.createElement(
      Animated.View,
      {
        onLayout: onLayout,
        style: [
          styles.panel_container,
          {
            height: getHeight,
          },
          style,
          {
            position: 'relative',
            borderWidth: 0,
            padding: 0,
          },
        ],
      },
      /*#__PURE__*/ React.createElement(Animated.Image, {
        source: require('../../assets/Hue.png'),
        style: [
          styles.panel_image,
          {
            borderRadius,
          },
          rotatePanelImage,
        ],
        resizeMode: 'stretch',
      }),
      /*#__PURE__*/ React.createElement(
        View,
        {
          style: [
            styles.panel_image,
            {
              borderRadius,
              flexDirection: isRtl ? 'row-reverse' : 'row',
              transform: [
                {
                  scaleX: reverseHorizontalChannels ? -1 : 1,
                },
              ],
            },
          ],
        },
        /*#__PURE__*/ React.createElement(Image, {
          source: require('../../assets/blackGradient.png'),
          style: {
            flex: 1,
            tintColor: '#fff',
          },
          resizeMode: 'stretch',
        }),
        /*#__PURE__*/ React.createElement(Image, {
          source: require('../../assets/blackGradient.png'),
          style: {
            flex: 1,
            transform: [
              {
                scaleX: -1,
              },
            ],
          },
          resizeMode: 'stretch',
        })
      ),
      /*#__PURE__*/ React.createElement(Thumb, {
        thumbShape,
        thumbSize,
        thumbColor,
        renderThumb,
        innerStyle: thumbInnerStyle,
        style: thumbStyle,
        handleStyle,
      })
    )
  );
}
//# sourceMappingURL=Panel4.js.map
