import React, { useContext, useCallback } from 'react';
import { ImageBackground, StyleSheet } from 'react-native';
import { GestureDetector, Gesture } from 'react-native-gesture-handler';
import Animated, { runOnJS, useAnimatedStyle, useSharedValue, withTiming } from 'react-native-reanimated';
import { styles } from '../../styles';
import { ConditionalRendering, HSVA2HSLA } from '../../utils';
import pickerContext from '../../AppContext';
import Thumb from '../Thumb/Thumb';
export function HueCircular(_ref) {
  let {
    adaptSpectrum: localAdaptSpectrum,
    thumbShape: localThumbShape,
    thumbSize: localThumbSize,
    thumbColor: localThumbColor,
    renderThumb: localRenderThumb,
    thumbStyle: localThumbStyle,
    thumbInnerStyle: localThumbInnerStyle,
    sliderThickness: localSliderThickness,
    children,
    style = {},
    containerStyle = {},
  } = _ref;
  const {
    hueValue,
    saturationValue,
    brightnessValue,
    onGestureChange,
    onGestureEnd,
    adaptSpectrum: globalAdaptSpectrum,
    thumbSize: globalThumbsSize,
    thumbShape: globalThumbShape,
    thumbColor: globalThumbsColor,
    renderThumb: globalRenderThumbs,
    thumbStyle: globalThumbsStyle,
    thumbInnerStyle: globalThumbsInnerStyle,
    sliderThickness: globalSliderThickness,
  } = useContext(pickerContext);
  const thumbShape = localThumbShape ?? globalThumbShape,
    thumbSize = localThumbSize ?? globalThumbsSize,
    thumbColor = localThumbColor ?? globalThumbsColor,
    renderThumb = localRenderThumb ?? globalRenderThumbs,
    thumbStyle = localThumbStyle ?? globalThumbsStyle ?? {},
    sliderThickness = localSliderThickness ?? globalSliderThickness,
    adaptSpectrum = localAdaptSpectrum ?? globalAdaptSpectrum,
    thumbInnerStyle = localThumbInnerStyle ?? globalThumbsInnerStyle ?? {};
  const isGestureActive = useSharedValue(false);
  const width = useSharedValue(0);
  const borderRadius = useSharedValue(0);
  const borderRadiusStyle = useAnimatedStyle(
    (function () {
      const _f = () => ({
        borderRadius: borderRadius.value,
      });
      _f._closure = {
        borderRadius,
      };
      _f.asString = 'function _f(){const{borderRadius}=jsThis._closure;{return{borderRadius:borderRadius.value};}}';
      _f.__workletHash = 14736265568603;
      _f.__location =
        'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Sliders\\HueCircular.tsx (56:45)';
      _f.__optimalization = 3;
      return _f;
    })(),
    [localThumbSize]
  );
  const handleScale = useSharedValue(1);
  const handleStyle = useAnimatedStyle(
    (function () {
      const _f = function () {
        const center = width.value / 2,
          distance = (width.value - sliderThickness) / 2,
          posY = width.value - Math.round(Math.sin((hueValue.value * Math.PI) / 180) * distance + center) - thumbSize / 2,
          posX = width.value - Math.round(Math.cos((hueValue.value * Math.PI) / 180) * distance + center) - thumbSize / 2;
        return {
          transform: [
            {
              translateX: posX,
            },
            {
              translateY: posY,
            },
            {
              scale: handleScale.value,
            },
            {
              rotate: hueValue.value + 90 + 'deg',
            },
          ],
        };
      };
      _f._closure = {
        width,
        sliderThickness,
        hueValue,
        thumbSize,
        handleScale,
      };
      _f.asString =
        "function _f(){const{width,sliderThickness,hueValue,thumbSize,handleScale}=jsThis._closure;{const center=width.value/2,distance=(width.value-sliderThickness)/2,posY=width.value-Math.round(Math.sin(hueValue.value*Math.PI/180)*distance+center)-thumbSize/2,posX=width.value-Math.round(Math.cos(hueValue.value*Math.PI/180)*distance+center)-thumbSize/2;return{transform:[{translateX:posX},{translateY:posY},{scale:handleScale.value},{rotate:hueValue.value+90+'deg'}]};}}";
      _f.__workletHash = 4325538069819;
      _f.__location =
        'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Sliders\\HueCircular.tsx (60:39)';
      _f.__optimalization = 2;
      return _f;
    })(),
    [localThumbSize]
  );
  const activeSaturationStyle = useAnimatedStyle(
    (function () {
      const _f = function () {
        if (!adaptSpectrum) return {};
        return {
          backgroundColor: HSVA2HSLA(0, 0, brightnessValue.value, 1 - saturationValue.value / 100),
        };
      };
      _f._closure = {
        adaptSpectrum,
        HSVA2HSLA,
        brightnessValue,
        saturationValue,
      };
      _f.asString =
        'function _f(){const{adaptSpectrum,HSVA2HSLA,brightnessValue,saturationValue}=jsThis._closure;{if(!adaptSpectrum)return{};return{backgroundColor:HSVA2HSLA(0,0,brightnessValue.value,1-saturationValue.value/100)};}}';
      _f.__workletHash = 8782818419074;
      _f.__location =
        'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Sliders\\HueCircular.tsx (75:49)';
      return _f;
    })()
  );
  const activeBrightnessStyle = useAnimatedStyle(
    (function () {
      const _f = function () {
        if (!adaptSpectrum) return {};
        return {
          backgroundColor: HSVA2HSLA(0, 0, 0, 1 - brightnessValue.value / 100),
        };
      };
      _f._closure = {
        adaptSpectrum,
        HSVA2HSLA,
        brightnessValue,
      };
      _f.asString =
        'function _f(){const{adaptSpectrum,HSVA2HSLA,brightnessValue}=jsThis._closure;{if(!adaptSpectrum)return{};return{backgroundColor:HSVA2HSLA(0,0,0,1-brightnessValue.value/100)};}}';
      _f.__workletHash = 12941901269723;
      _f.__location =
        'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Sliders\\HueCircular.tsx (79:49)';
      return _f;
    })()
  );
  const clipViewStyle = useAnimatedStyle(
    (function () {
      const _f = () => ({
        width: width.value - sliderThickness * 2,
        height: width.value - sliderThickness * 2,
        borderRadius: width.value / 2,
      });
      _f._closure = {
        width,
        sliderThickness,
      };
      _f.asString =
        'function _f(){const{width,sliderThickness}=jsThis._closure;{return{width:width.value-sliderThickness*2,height:width.value-sliderThickness*2,borderRadius:width.value/2};}}';
      _f.__workletHash = 13385850213536;
      _f.__location =
        'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Sliders\\HueCircular.tsx (83:41)';
      _f.__optimalization = 3;
      return _f;
    })()
  );
  const onGestureUpdate = (function () {
    const _f = function (_ref2) {
      let { x, y } = _ref2;
      if (!isGestureActive.value) return;
      const center = width.value / 2,
        dx = center - x,
        dy = center - y,
        theta = Math.atan2(dy, dx) * (180 / Math.PI),
        // [0 - 180] range
        angle = theta < 0 ? 360 + theta : theta,
        // [0 - 360] range
        newHueValue = Math.round(angle);
      if (hueValue.value === newHueValue) return;
      hueValue.value = newHueValue;
      runOnJS(onGestureChange)();
    };
    _f._closure = {
      isGestureActive,
      width,
      hueValue,
      runOnJS,
      onGestureChange,
    };
    _f.asString =
      'function _f({x:x,y:y}){const{isGestureActive,width,hueValue,runOnJS,onGestureChange}=jsThis._closure;{if(!isGestureActive.value)return;const center=width.value/2,dx=center-x,dy=center-y,theta=Math.atan2(dy,dx)*(180/Math.PI),angle=theta<0?360+theta:theta,newHueValue=Math.round(angle);if(hueValue.value===newHueValue)return;hueValue.value=newHueValue;runOnJS(onGestureChange)();}}';
    _f.__workletHash = 15238951088478;
    _f.__location =
      'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Sliders\\HueCircular.tsx (89:26)';
    return _f;
  })();
  const onGestureBegin = (function () {
    const _f = function (event) {
      const center = width.value / 2;
      const r = width.value / 2 - sliderThickness;
      const distance = Math.sqrt(Math.pow(event.x - center, 2) + Math.pow(event.y - center, 2));
      if (distance > r) isGestureActive.value = true;
      else return;
      handleScale.value = withTiming(1.2, {
        duration: 100,
      });
      onGestureUpdate(event);
    };
    _f._closure = {
      width,
      sliderThickness,
      isGestureActive,
      handleScale,
      withTiming,
      onGestureUpdate,
    };
    _f.asString =
      'function _f(event){const{width,sliderThickness,isGestureActive,handleScale,withTiming,onGestureUpdate}=jsThis._closure;{const center=width.value/2;const r=width.value/2-sliderThickness;const distance=Math.sqrt(Math.pow(event.x-center,2)+Math.pow(event.y-center,2));if(distance>r)isGestureActive.value=true;else return;handleScale.value=withTiming(1.2,{duration:100});onGestureUpdate(event);}}';
    _f.__workletHash = 1767298665208;
    _f.__location =
      'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Sliders\\HueCircular.tsx (106:25)';
    return _f;
  })();
  const onGestureFinish = (function () {
    const _f = function () {
      isGestureActive.value = false;
      handleScale.value = withTiming(1, {
        duration: 100,
      });
      runOnJS(onGestureEnd)();
    };
    _f._closure = {
      isGestureActive,
      handleScale,
      withTiming,
      runOnJS,
      onGestureEnd,
    };
    _f.asString =
      'function _f(){const{isGestureActive,handleScale,withTiming,runOnJS,onGestureEnd}=jsThis._closure;{isGestureActive.value=false;handleScale.value=withTiming(1,{duration:100});runOnJS(onGestureEnd)();}}';
    _f.__workletHash = 8485064255246;
    _f.__location =
      'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Sliders\\HueCircular.tsx (116:26)';
    return _f;
  })();
  const pan = Gesture.Pan().onBegin(onGestureBegin).onUpdate(onGestureUpdate).onEnd(onGestureFinish);
  const tap = Gesture.Tap().onTouchesUp(onGestureFinish);
  const longPress = Gesture.LongPress().onTouchesUp(onGestureFinish);
  const composed = Gesture.Exclusive(pan, tap, longPress);
  const onLayout = useCallback(_ref3 => {
    let {
      nativeEvent: { layout },
    } = _ref3;
    const layoutWidth = layout.width;
    width.value = layoutWidth;
    borderRadius.value = withTiming(layoutWidth / 2, {
      duration: 5,
    });
  }, []);
  return /*#__PURE__*/ React.createElement(
    GestureDetector,
    {
      gesture: composed,
    },
    /*#__PURE__*/ React.createElement(
      Animated.View,
      {
        onLayout: onLayout,
        style: [
          styles.panel_container,
          style,
          {
            position: 'relative',
            aspectRatio: 1,
            borderWidth: 0,
            padding: 0,
          },
          borderRadiusStyle,
        ],
      },
      /*#__PURE__*/ React.createElement(
        ImageBackground,
        {
          source: require('../../assets/circularHue.png'),
          style: [
            styles.panel_image,
            {
              justifyContent: 'center',
              alignItems: 'center',
            },
          ],
          resizeMode: 'stretch',
        },
        /*#__PURE__*/ React.createElement(
          ConditionalRendering,
          {
            render: adaptSpectrum,
          },
          /*#__PURE__*/ React.createElement(Animated.View, {
            style: [borderRadiusStyle, activeBrightnessStyle, StyleSheet.absoluteFillObject],
          }),
          /*#__PURE__*/ React.createElement(Animated.View, {
            style: [borderRadiusStyle, activeSaturationStyle, StyleSheet.absoluteFillObject],
          })
        ),
        /*#__PURE__*/ React.createElement(
          Animated.View,
          {
            style: [
              clipViewStyle,
              {
                backgroundColor: '#fff',
              },
              containerStyle,
            ],
          },
          children
        )
      ),
      /*#__PURE__*/ React.createElement(Thumb, {
        channel: 'h',
        thumbShape,
        thumbSize,
        thumbColor,
        renderThumb,
        innerStyle: thumbInnerStyle,
        style: thumbStyle,
        handleStyle,
        adaptSpectrum,
      })
    )
  );
}
//# sourceMappingURL=HueCircular.js.map
