import React, { useContext } from 'react';
import { GestureDetector, Gesture } from 'react-native-gesture-handler';
import Animated, { runOnJS, useAnimatedStyle, useSharedValue, withTiming } from 'react-native-reanimated';
import { clamp, getStyle, HSVA2RGBA, isRtl, isWeb, RenderNativeOnly, RGBA2HSVA } from '../../../utils';
import pickerContext from '../../../AppContext';
import Thumb from '../../Thumb/Thumb';
export function RedSlider(_ref) {
  let {
    thumbShape: localThumbShape,
    thumbSize: localThumbSize,
    thumbColor: localThumbColor,
    boundedThumb: localBoundedThumb,
    renderThumb: localRenderThumb,
    thumbStyle: localThumbStyle,
    thumbInnerStyle: localThumbInnerStyle,
    sliderThickness: localSliderThickness,
    style = {},
    vertical = false,
    reverse = false,
  } = _ref;
  const {
    hueValue,
    saturationValue,
    brightnessValue,
    onGestureChange,
    onGestureEnd,
    thumbSize: globalThumbSize,
    thumbShape: globalThumbShape,
    thumbColor: globalThumbColor,
    boundedThumb: globalBoundedThumb,
    renderThumb: globalRenderThumb,
    thumbStyle: globalThumbStyle,
    thumbInnerStyle: globalThumbInnerStyle,
    sliderThickness: globalSliderThickness,
  } = useContext(pickerContext);
  const thumbShape = localThumbShape ?? globalThumbShape,
    thumbSize = localThumbSize ?? globalThumbSize,
    thumbColor = localThumbColor ?? globalThumbColor,
    boundedThumb = localBoundedThumb ?? globalBoundedThumb,
    renderThumb = localRenderThumb ?? globalRenderThumb,
    thumbStyle = localThumbStyle ?? globalThumbStyle ?? {},
    thumbInnerStyle = localThumbInnerStyle ?? globalThumbInnerStyle ?? {},
    sliderThickness = localSliderThickness ?? globalSliderThickness;
  const borderRadius = getStyle(style, 'borderRadius') ?? 5,
    getWidth = getStyle(style, 'width'),
    getHeight = getStyle(style, 'height');
  const width = useSharedValue(vertical ? sliderThickness : typeof getWidth === 'number' ? getWidth : 0),
    height = useSharedValue(!vertical ? sliderThickness : typeof getHeight === 'number' ? getHeight : 0);
  const handleScale = useSharedValue(1);
  const handleStyle = useAnimatedStyle(
    (function () {
      const _f = function () {
        const { r } = HSVA2RGBA(hueValue.value, saturationValue.value, brightnessValue.value);
        const length = (vertical ? height.value : width.value) - (boundedThumb ? thumbSize : 0),
          percent = (r / 255) * length,
          pos = (reverse ? length - percent : percent) - (boundedThumb ? 0 : thumbSize / 2),
          posY = vertical ? pos : height.value / 2 - thumbSize / 2,
          posX = vertical ? width.value / 2 - thumbSize / 2 : pos;
        return {
          transform: [
            {
              translateY: posY,
            },
            {
              translateX: posX,
            },
            {
              scale: handleScale.value,
            },
          ],
        };
      };
      _f._closure = {
        HSVA2RGBA,
        hueValue,
        saturationValue,
        brightnessValue,
        vertical,
        height,
        width,
        boundedThumb,
        thumbSize,
        reverse,
        handleScale,
      };
      _f.asString =
        'function _f(){const{HSVA2RGBA,hueValue,saturationValue,brightnessValue,vertical,height,width,boundedThumb,thumbSize,reverse,handleScale}=jsThis._closure;{const{r:r}=HSVA2RGBA(hueValue.value,saturationValue.value,brightnessValue.value);const length=(vertical?height.value:width.value)-(boundedThumb?thumbSize:0),percent=r/255*length,pos=(reverse?length-percent:percent)-(boundedThumb?0:thumbSize/2),posY=vertical?pos:height.value/2-thumbSize/2,posX=vertical?width.value/2-thumbSize/2:pos;return{transform:[{translateY:posY},{translateX:posX},{scale:handleScale.value}]};}}';
      _f.__workletHash = 9862581947881;
      _f.__location =
        'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Sliders\\RGB\\RedSlider.tsx (60:39)';
      _f.__optimalization = 2;
      return _f;
    })(),
    [localThumbSize, vertical, reverse]
  );
  const onGestureUpdate = (function () {
    const _f = function (_ref2) {
      let { x, y } = _ref2;
      const { r, g, b } = HSVA2RGBA(hueValue.value, saturationValue.value, brightnessValue.value);
      const length = (vertical ? height.value : width.value) - (boundedThumb ? thumbSize : 0),
        pos = clamp((vertical ? y : x) - (boundedThumb ? thumbSize / 2 : 0), length),
        value = Math.round((pos / length) * 255),
        newRedValue = reverse ? 255 - value : value;
      if (newRedValue === r) return;
      const { h, s, v } = RGBA2HSVA(newRedValue, g, b);
      hueValue.value = h;
      saturationValue.value = s;
      brightnessValue.value = v;
      runOnJS(onGestureChange)();
    };
    _f._closure = {
      HSVA2RGBA,
      hueValue,
      saturationValue,
      brightnessValue,
      vertical,
      height,
      width,
      boundedThumb,
      thumbSize,
      clamp,
      reverse,
      RGBA2HSVA,
      runOnJS,
      onGestureChange,
    };
    _f.asString =
      'function _f({x:x,y:y}){const{HSVA2RGBA,hueValue,saturationValue,brightnessValue,vertical,height,width,boundedThumb,thumbSize,clamp,reverse,RGBA2HSVA,runOnJS,onGestureChange}=jsThis._closure;{const{r:r,g:g,b:b}=HSVA2RGBA(hueValue.value,saturationValue.value,brightnessValue.value);const length=(vertical?height.value:width.value)-(boundedThumb?thumbSize:0),pos=clamp((vertical?y:x)-(boundedThumb?thumbSize/2:0),length),value=Math.round(pos/length*255),newRedValue=reverse?255-value:value;if(newRedValue===r)return;const{h:h,s:s,v:v}=RGBA2HSVA(newRedValue,g,b);hueValue.value=h;saturationValue.value=s;brightnessValue.value=v;runOnJS(onGestureChange)();}}';
    _f.__workletHash = 2581807696806;
    _f.__location =
      'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Sliders\\RGB\\RedSlider.tsx (73:26)';
    return _f;
  })();
  const onGestureBegin = (function () {
    const _f = function (event) {
      handleScale.value = withTiming(1.2, {
        duration: 100,
      });
      onGestureUpdate(event);
    };
    _f._closure = {
      handleScale,
      withTiming,
      onGestureUpdate,
    };
    _f.asString =
      'function _f(event){const{handleScale,withTiming,onGestureUpdate}=jsThis._closure;{handleScale.value=withTiming(1.2,{duration:100});onGestureUpdate(event);}}';
    _f.__workletHash = 14773240202957;
    _f.__location =
      'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Sliders\\RGB\\RedSlider.tsx (93:25)';
    return _f;
  })();
  const onGestureFinish = (function () {
    const _f = function () {
      handleScale.value = withTiming(1, {
        duration: 100,
      });
      runOnJS(onGestureEnd)();
    };
    _f._closure = {
      handleScale,
      withTiming,
      runOnJS,
      onGestureEnd,
    };
    _f.asString =
      'function _f(){const{handleScale,withTiming,runOnJS,onGestureEnd}=jsThis._closure;{handleScale.value=withTiming(1,{duration:100});runOnJS(onGestureEnd)();}}';
    _f.__workletHash = 6379049506140;
    _f.__location =
      'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Sliders\\RGB\\RedSlider.tsx (98:26)';
    return _f;
  })();
  const pan = Gesture.Pan().onBegin(onGestureBegin).onUpdate(onGestureUpdate).onEnd(onGestureFinish);
  const tap = Gesture.Tap().onTouchesUp(onGestureFinish);
  const longPress = Gesture.LongPress().onTouchesUp(onGestureFinish);
  const composed = Gesture.Exclusive(pan, tap, longPress);
  const onLayout = _ref3 => {
    let {
      nativeEvent: { layout },
    } = _ref3;
    if (!vertical)
      width.value = withTiming(layout.width, {
        duration: 5,
      });
    if (vertical)
      height.value = withTiming(layout.height, {
        duration: 5,
      });
  };
  const greenBlue = useAnimatedStyle(
    (function () {
      const _f = function () {
        const { g, b } = HSVA2RGBA(hueValue.value, saturationValue.value, brightnessValue.value);
        if (isWeb) {
          const deg = vertical ? (reverse ? 180 : 0) : reverse ? 90 : 270;
          return {
            background: `linear-gradient(${deg}deg, rgb(255, ${g}, ${b}) 0%, rgb(0, ${g}, ${b}) 100%)`,
          };
        }
        return {
          backgroundColor: `rgb(0, ${g}, ${b})`,
        };
      };
      _f._closure = {
        HSVA2RGBA,
        hueValue,
        saturationValue,
        brightnessValue,
        isWeb,
        vertical,
        reverse,
      };
      _f.asString =
        'function _f(){const{HSVA2RGBA,hueValue,saturationValue,brightnessValue,isWeb,vertical,reverse}=jsThis._closure;{const{g:g,b:b}=HSVA2RGBA(hueValue.value,saturationValue.value,brightnessValue.value);if(isWeb){const deg=vertical?reverse?180:0:reverse?90:270;return{background:"linear-gradient("+deg+"deg, rgb(255, "+g+", "+b+") 0%, rgb(0, "+g+", "+b+") 100%)"};}return{backgroundColor:"rgb(0, "+g+", "+b+")"};}}';
      _f.__workletHash = 15172981252445;
      _f.__location =
        'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Sliders\\RGB\\RedSlider.tsx (114:37)';
      return _f;
    })()
  );
  const imageStyle = useAnimatedStyle(
    (function () {
      const _f = function () {
        if (isWeb) return {};
        const imageRotate = vertical ? (reverse ? '90deg' : '270deg') : reverse ? '0deg' : '180deg';
        const imageTranslateY = ((height.value - width.value) / 2) * ((reverse && isRtl) || (!reverse && !isRtl) ? -1 : 1);
        const { g, b } = HSVA2RGBA(hueValue.value, saturationValue.value, brightnessValue.value);
        return {
          tintColor: `rgb(255, ${g}, ${b})`,
          width: vertical ? height.value : '100%',
          height: vertical ? width.value : '100%',
          borderRadius,
          transform: [
            {
              rotate: imageRotate,
            },
            {
              translateX: vertical ? ((height.value - width.value) / 2) * (reverse ? 1 : -1) : 0,
            },
            {
              translateY: vertical ? imageTranslateY : 0,
            },
          ],
        };
      };
      _f._closure = {
        isWeb,
        vertical,
        reverse,
        height,
        width,
        isRtl,
        HSVA2RGBA,
        hueValue,
        saturationValue,
        brightnessValue,
        borderRadius,
      };
      _f.asString =
        "function _f(){const{isWeb,vertical,reverse,height,width,isRtl,HSVA2RGBA,hueValue,saturationValue,brightnessValue,borderRadius}=jsThis._closure;{if(isWeb)return{};const imageRotate=vertical?reverse?'90deg':'270deg':reverse?'0deg':'180deg';const imageTranslateY=(height.value-width.value)/2*(reverse&&isRtl||!reverse&&!isRtl?-1:1);const{g:g,b:b}=HSVA2RGBA(hueValue.value,saturationValue.value,brightnessValue.value);return{tintColor:\"rgb(255, \"+g+\", \"+b+\")\",width:vertical?height.value:'100%',height:vertical?width.value:'100%',borderRadius:borderRadius,transform:[{rotate:imageRotate},{translateX:vertical?(height.value-width.value)/2*(reverse?1:-1):0},{translateY:vertical?imageTranslateY:0}]};}}";
      _f.__workletHash = 7193494409894;
      _f.__location =
        'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Sliders\\RGB\\RedSlider.tsx (123:38)';
      return _f;
    })(),
    [vertical, reverse, sliderThickness]
  );
  const thicknessStyle = vertical
    ? {
        width: sliderThickness,
      }
    : {
        height: sliderThickness,
      };
  return /*#__PURE__*/ React.createElement(
    GestureDetector,
    {
      gesture: composed,
    },
    /*#__PURE__*/ React.createElement(
      Animated.View,
      {
        onLayout: onLayout,
        style: [
          {
            borderRadius,
          },
          style,
          {
            position: 'relative',
            borderWidth: 0,
            padding: 0,
          },
          thicknessStyle,
          greenBlue,
        ],
      },
      /*#__PURE__*/ React.createElement(
        RenderNativeOnly,
        null,
        /*#__PURE__*/ React.createElement(Animated.Image, {
          source: require('../../../assets/blackGradient.png'),
          style: imageStyle,
        })
      ),
      /*#__PURE__*/ React.createElement(Thumb, {
        thumbShape,
        thumbSize,
        thumbColor,
        renderThumb,
        handleStyle,
        innerStyle: thumbInnerStyle,
        style: thumbStyle,
        vertical,
      })
    )
  );
}
//# sourceMappingURL=RedSlider.js.map
