import React, { useContext } from 'react';
import { StyleSheet } from 'react-native';
import { GestureDetector, Gesture } from 'react-native-gesture-handler';
import Animated, { runOnJS, useAnimatedStyle, useSharedValue, withTiming } from 'react-native-reanimated';
import { clamp, ConditionalRendering, getStyle, HSVA2HSLA, isRtl } from '../../utils';
import pickerContext from '../../AppContext';
import Thumb from '../Thumb/Thumb';
export function SaturationSlider(_ref) {
  let {
    adaptSpectrum: localAdaptSpectrum,
    thumbShape: localThumbShape,
    thumbSize: localThumbSize,
    thumbColor: localThumbColor,
    boundedThumb: localBoundedThumb,
    renderThumb: localRenderThumb,
    thumbStyle: localThumbStyle,
    thumbInnerStyle: localThumbInnerStyle,
    sliderThickness: localSliderThickness,
    style = {},
    vertical = false,
    reverse = false,
  } = _ref;
  const {
    hueValue,
    saturationValue,
    brightnessValue,
    onGestureChange,
    onGestureEnd,
    adaptSpectrum: globalAdaptSpectrum,
    thumbSize: globalThumbsSize,
    thumbShape: globalThumbsShape,
    thumbColor: globalThumbsColor,
    boundedThumb: globalBoundedThumb,
    renderThumb: globalRenderThumbs,
    thumbStyle: globalThumbsStyle,
    thumbInnerStyle: globalThumbsInnerStyle,
    sliderThickness: globalSliderThickness,
  } = useContext(pickerContext);
  const thumbShape = localThumbShape ?? globalThumbsShape,
    thumbSize = localThumbSize ?? globalThumbsSize,
    thumbColor = localThumbColor ?? globalThumbsColor,
    boundedThumb = localBoundedThumb ?? globalBoundedThumb,
    renderThumb = localRenderThumb ?? globalRenderThumbs,
    thumbStyle = localThumbStyle ?? globalThumbsStyle ?? {},
    thumbInnerStyle = localThumbInnerStyle ?? globalThumbsInnerStyle ?? {},
    adaptSpectrum = localAdaptSpectrum ?? globalAdaptSpectrum,
    sliderThickness = localSliderThickness ?? globalSliderThickness;
  const borderRadius = getStyle(style, 'borderRadius') ?? 5,
    getWidth = getStyle(style, 'width'),
    getHeight = getStyle(style, 'height');
  const width = useSharedValue(vertical ? sliderThickness : typeof getWidth === 'number' ? getWidth : 0),
    height = useSharedValue(!vertical ? sliderThickness : typeof getHeight === 'number' ? getHeight : 0);
  const handleScale = useSharedValue(1);
  const handleStyle = useAnimatedStyle(
    (function () {
      const _f = function () {
        const length = (vertical ? height.value : width.value) - (boundedThumb ? thumbSize : 0),
          percent = (saturationValue.value / 100) * length,
          pos = (reverse ? length - percent : percent) - (boundedThumb ? 0 : thumbSize / 2),
          posY = vertical ? pos : height.value / 2 - thumbSize / 2,
          posX = vertical ? width.value / 2 - thumbSize / 2 : pos;
        return {
          transform: [
            {
              translateY: posY,
            },
            {
              translateX: posX,
            },
            {
              scale: handleScale.value,
            },
          ],
        };
      };
      _f._closure = {
        vertical,
        height,
        width,
        boundedThumb,
        thumbSize,
        saturationValue,
        reverse,
        handleScale,
      };
      _f.asString =
        'function _f(){const{vertical,height,width,boundedThumb,thumbSize,saturationValue,reverse,handleScale}=jsThis._closure;{const length=(vertical?height.value:width.value)-(boundedThumb?thumbSize:0),percent=saturationValue.value/100*length,pos=(reverse?length-percent:percent)-(boundedThumb?0:thumbSize/2),posY=vertical?pos:height.value/2-thumbSize/2,posX=vertical?width.value/2-thumbSize/2:pos;return{transform:[{translateY:posY},{translateX:posX},{scale:handleScale.value}]};}}';
      _f.__workletHash = 5659029706794;
      _f.__location =
        'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Sliders\\SaturationSlider.tsx (64:39)';
      _f.__optimalization = 3;
      return _f;
    })(),
    [localThumbSize, vertical, reverse]
  );
  const activeColorStyle = useAnimatedStyle(
    (function () {
      const _f = function () {
        return {
          backgroundColor: HSVA2HSLA(hueValue.value, 100, 100),
        };
      };
      _f._closure = {
        HSVA2HSLA,
        hueValue,
      };
      _f.asString =
        'function _f(){const{HSVA2HSLA,hueValue}=jsThis._closure;{return{backgroundColor:HSVA2HSLA(hueValue.value,100,100)};}}';
      _f.__workletHash = 2577887441425;
      _f.__location =
        'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Sliders\\SaturationSlider.tsx (75:44)';
      _f.__optimalization = 2;
      return _f;
    })()
  );
  const activeBrightnessStyle = useAnimatedStyle(
    (function () {
      const _f = function () {
        if (!adaptSpectrum) return {};
        return {
          backgroundColor: HSVA2HSLA(0, 0, 0, 1 - brightnessValue.value / 100),
        };
      };
      _f._closure = {
        adaptSpectrum,
        HSVA2HSLA,
        brightnessValue,
      };
      _f.asString =
        'function _f(){const{adaptSpectrum,HSVA2HSLA,brightnessValue}=jsThis._closure;{if(!adaptSpectrum)return{};return{backgroundColor:HSVA2HSLA(0,0,0,1-brightnessValue.value/100)};}}';
      _f.__workletHash = 12941901269723;
      _f.__location =
        'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Sliders\\SaturationSlider.tsx (78:49)';
      return _f;
    })()
  );
  const onGestureUpdate = (function () {
    const _f = function (_ref2) {
      let { x, y } = _ref2;
      const length = (vertical ? height.value : width.value) - (boundedThumb ? thumbSize : 0),
        pos = clamp((vertical ? y : x) - (boundedThumb ? thumbSize / 2 : 0), length),
        value = Math.round((pos / length) * 100),
        newSaturationValue = reverse ? 100 - value : value;
      if (saturationValue.value === newSaturationValue) return;
      saturationValue.value = newSaturationValue;
      runOnJS(onGestureChange)();
    };
    _f._closure = {
      vertical,
      height,
      width,
      boundedThumb,
      thumbSize,
      clamp,
      reverse,
      saturationValue,
      runOnJS,
      onGestureChange,
    };
    _f.asString =
      'function _f({x:x,y:y}){const{vertical,height,width,boundedThumb,thumbSize,clamp,reverse,saturationValue,runOnJS,onGestureChange}=jsThis._closure;{const length=(vertical?height.value:width.value)-(boundedThumb?thumbSize:0),pos=clamp((vertical?y:x)-(boundedThumb?thumbSize/2:0),length),value=Math.round(pos/length*100),newSaturationValue=reverse?100-value:value;if(saturationValue.value===newSaturationValue)return;saturationValue.value=newSaturationValue;runOnJS(onGestureChange)();}}';
    _f.__workletHash = 320748792034;
    _f.__location =
      'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Sliders\\SaturationSlider.tsx (83:26)';
    return _f;
  })();
  const onGestureBegin = (function () {
    const _f = function (event) {
      handleScale.value = withTiming(1.2, {
        duration: 100,
      });
      onGestureUpdate(event);
    };
    _f._closure = {
      handleScale,
      withTiming,
      onGestureUpdate,
    };
    _f.asString =
      'function _f(event){const{handleScale,withTiming,onGestureUpdate}=jsThis._closure;{handleScale.value=withTiming(1.2,{duration:100});onGestureUpdate(event);}}';
    _f.__workletHash = 14773240202957;
    _f.__location =
      'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Sliders\\SaturationSlider.tsx (96:25)';
    return _f;
  })();
  const onGestureFinish = (function () {
    const _f = function () {
      handleScale.value = withTiming(1, {
        duration: 100,
      });
      runOnJS(onGestureEnd)();
    };
    _f._closure = {
      handleScale,
      withTiming,
      runOnJS,
      onGestureEnd,
    };
    _f.asString =
      'function _f(){const{handleScale,withTiming,runOnJS,onGestureEnd}=jsThis._closure;{handleScale.value=withTiming(1,{duration:100});runOnJS(onGestureEnd)();}}';
    _f.__workletHash = 6379049506140;
    _f.__location =
      'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Sliders\\SaturationSlider.tsx (101:26)';
    return _f;
  })();
  const pan = Gesture.Pan().onBegin(onGestureBegin).onUpdate(onGestureUpdate).onEnd(onGestureFinish);
  const tap = Gesture.Tap().onTouchesUp(onGestureFinish);
  const longPress = Gesture.LongPress().onTouchesUp(onGestureFinish);
  const composed = Gesture.Exclusive(pan, tap, longPress);
  const onLayout = _ref3 => {
    let {
      nativeEvent: { layout },
    } = _ref3;
    if (!vertical)
      width.value = withTiming(layout.width, {
        duration: 5,
      });
    if (vertical)
      height.value = withTiming(layout.height, {
        duration: 5,
      });
  };
  const imageStyle = useAnimatedStyle(
    (function () {
      const _f = function () {
        const imageRotate = vertical ? (reverse ? '270deg' : '90deg') : reverse ? '180deg' : '0deg';
        const imageTranslateY = ((height.value - width.value) / 2) * ((reverse && isRtl) || (!reverse && !isRtl) ? 1 : -1);
        return {
          width: vertical ? height.value : '100%',
          height: vertical ? width.value : '100%',
          borderRadius,
          transform: [
            {
              rotate: imageRotate,
            },
            {
              translateX: vertical ? ((height.value - width.value) / 2) * (reverse ? -1 : 1) : 0,
            },
            {
              translateY: vertical ? imageTranslateY : 0,
            },
          ],
        };
      };
      _f._closure = {
        vertical,
        reverse,
        height,
        width,
        isRtl,
        borderRadius,
      };
      _f.asString =
        "function _f(){const{vertical,reverse,height,width,isRtl,borderRadius}=jsThis._closure;{const imageRotate=vertical?reverse?'270deg':'90deg':reverse?'180deg':'0deg';const imageTranslateY=(height.value-width.value)/2*(reverse&&isRtl||!reverse&&!isRtl?1:-1);return{width:vertical?height.value:'100%',height:vertical?width.value:'100%',borderRadius:borderRadius,transform:[{rotate:imageRotate},{translateX:vertical?(height.value-width.value)/2*(reverse?-1:1):0},{translateY:vertical?imageTranslateY:0}]};}}";
      _f.__workletHash = 9330412360531;
      _f.__location =
        'D:\\Development\\--- Packages ---\\reanimated-color-picker\\src\\components\\Sliders\\SaturationSlider.tsx (117:38)';
      _f.__optimalization = 3;
      return _f;
    })(),
    [vertical, reverse, sliderThickness]
  );
  const thicknessStyle = vertical
    ? {
        width: sliderThickness,
      }
    : {
        height: sliderThickness,
      };
  return /*#__PURE__*/ React.createElement(
    GestureDetector,
    {
      gesture: composed,
    },
    /*#__PURE__*/ React.createElement(
      Animated.View,
      {
        onLayout: onLayout,
        style: [
          {
            borderRadius,
          },
          style,
          {
            position: 'relative',
            borderWidth: 0,
            padding: 0,
          },
          thicknessStyle,
          activeColorStyle,
        ],
      },
      /*#__PURE__*/ React.createElement(Animated.Image, {
        source: require('../../assets/blackGradient.png'),
        style: [
          imageStyle,
          {
            tintColor: '#fff',
          },
        ],
      }),
      /*#__PURE__*/ React.createElement(
        ConditionalRendering,
        {
          render: adaptSpectrum,
        },
        /*#__PURE__*/ React.createElement(Animated.View, {
          style: [
            {
              borderRadius,
            },
            activeBrightnessStyle,
            StyleSheet.absoluteFillObject,
          ],
        })
      ),
      /*#__PURE__*/ React.createElement(Thumb, {
        channel: 's',
        thumbShape,
        thumbSize,
        thumbColor,
        renderThumb,
        handleStyle,
        innerStyle: thumbInnerStyle,
        style: thumbStyle,
        vertical,
        adaptSpectrum,
      })
    )
  );
}
//# sourceMappingURL=SaturationSlider.js.map
