import React, { useContext, useState } from 'react';
import { View, Text, Pressable, Image, StyleSheet } from 'react-native';
import { styles } from '../../styles.js';
import { ConditionalRendering, getStyle } from '../../utils.js';
import pickerContext from '../../AppContext.js';
import HexWidget from './Widgets/HexWidget.js';
import RgbWidget from './Widgets/RgbWidget.js';
import HslWidget from './Widgets/HslWidget.js';
import HwbWidget from './Widgets/HwbWidget.js';
import HsvWidget from './Widgets/HsvWidget.js';
const defaultFormats = ['HEX', 'RGB', 'HSL', 'HWB', 'HSV'];
export function InputWidget({
  defaultFormat = 'HEX',
  formats = defaultFormats,
  iconColor = 'black',
  containerStyle = {},
  inputStyle = {},
  inputTitleStyle = {},
  iconStyle = {},
  inputProps = {},
}) {
  const { setColor, returnedResults, hueValue, saturationValue, brightnessValue, alphaValue, onGestureChange, onGestureEnd } =
    useContext(pickerContext);
  const [format, setFormat] = useState(formats.includes(defaultFormat) ? defaultFormat : formats[0] ?? 'HEX');
  const onChange = color => {
    setColor(color);
    onGestureChange(color);
    onGestureEnd(color);
  };
  const cycle = () => {
    const index = formats.indexOf(format);
    const nextIndex = (index + 1) % formats.length;
    setFormat(formats[nextIndex]);
  };
  const inputsProps = {
    onChange,
    returnedResults,
    hueValue,
    saturationValue,
    brightnessValue,
    alphaValue,
    inputStyle,
    inputTitleStyle,
    inputProps,
  };
  const Input = () => {
    switch (format) {
      case 'HEX':
        return <HexWidget {...inputsProps} />;
      case 'RGB':
        return <RgbWidget {...inputsProps} />;
      case 'HSL':
        return <HslWidget {...inputsProps} />;
      case 'HWB':
        return <HwbWidget {...inputsProps} />;
      case 'HSV':
        return <HsvWidget {...inputsProps} />;
    }
  };
  const gap = getStyle(containerStyle, 'gap') ?? 5;
  const iconWidth = getStyle(iconStyle, 'width') ?? 24;
  const buttonIconStyle = StyleSheet.flatten([styles.arrowButton, iconStyle]);
  return (
    <View style={[styles.container, containerStyle]}>
      <View style={[styles.inputsWrapper, { gap }]}>
        <Input />
      </View>

      <ConditionalRendering render={formats.length > 1}>
        <View style={{ width: iconWidth }}>
          <Pressable onPress={cycle}>
            <Image style={[buttonIconStyle, { tintColor: iconColor }]} source={require('../../assets/arrow-icon.png')} />
          </Pressable>
          <Text style={styles.inputTitle}> </Text>
        </View>
      </ConditionalRendering>
    </View>
  );
}
